@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# Minimal perl lexer/parser. No quote escapes currently handled.
+# Minimal LISP lexer/parser. No quote escapes currently handled.
 sub parse_lisp
 {
 	local($_) = @_;
@@ -327,6 +327,7 @@ EOT
 
 
 open(STDOUT,">typemap.gtk") or die "Unable to write to typemap.gtk: $!";
+print "\n\n# Do not edit this file, as it is automatically generated by gendefs.pl\n\n";
 print "TYPEMAP\n";
 $i = 0;
 foreach (sort keys %enum) {
@@ -356,6 +357,9 @@ foreach (sort keys %struct) {
 
 open(STDOUT,">GtkDefs.h") or die "Unable to write to GtkDefs.h: $!";;
 print <<"EOT";
+
+/* Do not edit this file, as it is automatically generated by gendefs.pl */
+
 extern HV * pGtkType[];
 extern char * pGtkTypeName[];
 extern HV * pG_EnumHash;
@@ -391,6 +395,7 @@ foreach (sort keys %enum) {
 foreach (sort keys %flags) {
 	print "#define pGF_$_ pGtkType[$i]\n";
 	print "#define pGFName_$_ pGtkTypeName[$i]\n";
+	# Generate arrays
 	print "#define newSV$_(v) newSVFlagsHash(v, pGFName_$_, pGF_$_, 1)\n";
 	print "#define Sv$_(v) SvFlagsHash(v, pGFName_$_, pGF_$_)\n";
 	print "typedef $_ $flags{$_}->{xsname};\n";
@@ -455,6 +460,8 @@ foreach (sort keys %boxed) {
 print "*/\n";
 
 open(STDOUT,">GtkTypes.pm") or die "Unable to write to GtkTypes.pm: $!";
+print "\n\n# Do not edit this file, as it is automatically generated by gendefs.pl\n\n";
+
 print "package Gtk::Types;\n";
 foreach (sort keys %object) {
 	if (defined $object{$_}->{parent}) {
@@ -468,6 +475,9 @@ print "1;\n";
 open(STDOUT,">GtkDefs.c")  or die "Unable to write to GtkDefs.c: $!";
 
 print <<"EOT";
+
+/* Do not edit this file, as it is automatically generated by gendefs.pl*/
+
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
@@ -550,7 +560,7 @@ SV * GtkGetArg(GtkArg * a)
 				croak("Unable to return a foreign signal type to Perl");
 
 			result = newSVsv(*s);
-			return;
+			break;
 		}
 		case GTK_TYPE_ENUM:
 EOT
@@ -690,7 +700,7 @@ void GtkSetArg(GtkArg * a, SV * v, SV * Class, GtkObject * Object)
 
 			GTK_VALUE_SIGNAL(*a).f = 0;
 			GTK_VALUE_SIGNAL(*a).d = args;
-			return;
+			break;
 		}
 		case GTK_TYPE_POINTER:
 #if 0
@@ -1025,6 +1035,9 @@ print "}\n";
 
 open(STDOUT,">boxed.xsh") or die "Unable to write to boxed.xsh: $!";
 
+print "\n\n# Do not edit this file, as it is automatically generated by gendefs.pl\n\n";
+
+
 foreach (sort keys %boxed) {
 	print <<"EOT";
 	
@@ -1056,6 +1069,8 @@ EOT
 
 open(STDOUT,">objects.xsh") or die "Unable to write to objects.xsh: $!";
 
+print "\n\n# Do not edit this file, as it is automatically generated by gendefs.pl\n\n";
+
 foreach (sort keys %object) {
 	next if not length $object{$_}->{prefix};
 
@@ -1109,6 +1124,9 @@ EOT
 }
 
 open(STDOUT,">Objects.xpl") or die "Unable to write to Objects.xpl: $!";
+
+print "\n\n# Do not edit this file, as it is automatically generated by gendefs.pl\n\n";
+
 print "\"\n";
 foreach (sort keys %object) {
 	print "$_.o\n";
@@ -1302,3 +1320,36 @@ __END__;
 (define-boxed GtkBoxChild
 	"(void)"
 	"(void)")
+
+;; Waiting for GtkPacker to be released
+;(define-object GtkPacker (GtkContainer))
+;
+;(define-enum GtkAnchor
+;	(center GTK_ANCHOR_CENTER)
+;	(north GTK_ANCHOR_N)
+;	(ne GTK_ANCHOR_NE)
+;	(east GTK_ANCHOR_E)
+;	(se GTK_ANCHOR_SE)
+;	(south GTK_ANCHOR_S)
+;	(sw GTK_ANCHOR_SW)
+;	(west GTK_ANCHOR_W)
+;	(nw GTK_ANCHOR_NW))
+;
+;(define-enum GtkSide
+;	(top GTK_SIDE_TOP)
+;	(bottom GTK_SIDE_BOTTOM)
+;	(left GTK_SIDE_LEFT)
+;	(right GTK_SIDE_RIGHT))
+;
+;(define-flags GtkPackerOptions
+;	(pack-expand GTK_PACK_EXPAND)
+;	(fill-x GTK_FILL_X)
+;	(fill-y GTK_FILL_Y))
+;
+;(define-boxed GtkPackerChild
+;	"(void)"
+;	"(void)")
+
+(define-boxed GdkColorContext
+	"(void)"
+	"(void)")
